/*  
 *  Copyright (c) 2005 Dan Gudmundsson
 *  See the file "license.terms" for information on usage and redistribution
 *  of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 *     $Id$
 *
 */
{ glBlendColorFunc,  "glBlendColor", egl_blendColor, &esdl_glBlendColor},
{ glBlendEquationFunc,  "glBlendEquation", egl_blendEquation, &esdl_glBlendEquation},
{ glDrawRangeElementsFunc,  "glDrawRangeElements", egl_drawRangeElements, &esdl_glDrawRangeElements},
{ glColorTableFunc,  "glColorTable", egl_colorTable, &esdl_glColorTable},
{ glColorTableParameterfvFunc,  "glColorTableParameterfv", egl_colorTableParameterfv, &esdl_glColorTableParameterfv},
{ glColorTableParameterivFunc,  "glColorTableParameteriv", egl_colorTableParameteriv, &esdl_glColorTableParameteriv},
{ glCopyColorTableFunc,  "glCopyColorTable", egl_copyColorTable, &esdl_glCopyColorTable},
{ glGetColorTableFunc,  "glGetColorTable", egl_getColorTable, &esdl_glGetColorTable},
{ glGetColorTableParameterfvFunc,  "glGetColorTableParameterfv", egl_getColorTableParameterfv, &esdl_glGetColorTableParameterfv},
{ glGetColorTableParameterivFunc,  "glGetColorTableParameteriv", egl_getColorTableParameteriv, &esdl_glGetColorTableParameteriv},
{ glColorSubTableFunc,  "glColorSubTable", egl_colorSubTable, &esdl_glColorSubTable},
{ glCopyColorSubTableFunc,  "glCopyColorSubTable", egl_copyColorSubTable, &esdl_glCopyColorSubTable},
{ glConvolutionFilter1DFunc,  "glConvolutionFilter1D", egl_convolutionFilter1D, &esdl_glConvolutionFilter1D},
{ glConvolutionFilter2DFunc,  "glConvolutionFilter2D", egl_convolutionFilter2D, &esdl_glConvolutionFilter2D},
{ glConvolutionParameterfFunc,  "glConvolutionParameterf", egl_convolutionParameterf, &esdl_glConvolutionParameterf},
{ glConvolutionParameterfvFunc,  "glConvolutionParameterfv", egl_convolutionParameterfv, &esdl_glConvolutionParameterfv},
{ glConvolutionParameteriFunc,  "glConvolutionParameteri", egl_convolutionParameteri, &esdl_glConvolutionParameteri},
{ glConvolutionParameterivFunc,  "glConvolutionParameteriv", egl_convolutionParameteriv, &esdl_glConvolutionParameteriv},
{ glCopyConvolutionFilter1DFunc,  "glCopyConvolutionFilter1D", egl_copyConvolutionFilter1D, &esdl_glCopyConvolutionFilter1D},
{ glCopyConvolutionFilter2DFunc,  "glCopyConvolutionFilter2D", egl_copyConvolutionFilter2D, &esdl_glCopyConvolutionFilter2D},
{ glGetConvolutionFilterFunc,  "glGetConvolutionFilter", egl_getConvolutionFilter, &esdl_glGetConvolutionFilter},
{ glGetConvolutionParameterfvFunc,  "glGetConvolutionParameterfv", egl_getConvolutionParameterfv, &esdl_glGetConvolutionParameterfv},
{ glGetConvolutionParameterivFunc,  "glGetConvolutionParameteriv", egl_getConvolutionParameteriv, &esdl_glGetConvolutionParameteriv},
{ glGetSeparableFilterFunc,  "glGetSeparableFilter", egl_getSeparableFilter, &esdl_glGetSeparableFilter},
{ glSeparableFilter2DFunc,  "glSeparableFilter2D", egl_separableFilter2D, &esdl_glSeparableFilter2D},
{ glGetHistogramFunc,  "glGetHistogram", egl_getHistogram, &esdl_glGetHistogram},
{ glGetHistogramParameterfvFunc,  "glGetHistogramParameterfv", egl_getHistogramParameterfv, &esdl_glGetHistogramParameterfv},
{ glGetHistogramParameterivFunc,  "glGetHistogramParameteriv", egl_getHistogramParameteriv, &esdl_glGetHistogramParameteriv},
{ glGetMinmaxFunc,  "glGetMinmax", egl_getMinmax, &esdl_glGetMinmax},
{ glGetMinmaxParameterfvFunc,  "glGetMinmaxParameterfv", egl_getMinmaxParameterfv, &esdl_glGetMinmaxParameterfv},
{ glGetMinmaxParameterivFunc,  "glGetMinmaxParameteriv", egl_getMinmaxParameteriv, &esdl_glGetMinmaxParameteriv},
{ glHistogramFunc,  "glHistogram", egl_histogram, &esdl_glHistogram},
{ glMinmaxFunc,  "glMinmax", egl_minmax, &esdl_glMinmax},
{ glResetHistogramFunc,  "glResetHistogram", egl_resetHistogram, &esdl_glResetHistogram},
{ glResetMinmaxFunc,  "glResetMinmax", egl_resetMinmax, &esdl_glResetMinmax},
{ glTexImage3DFunc,  "glTexImage3D", egl_texImage3D, &esdl_glTexImage3D},
{ glTexSubImage3DFunc,  "glTexSubImage3D", egl_texSubImage3D, &esdl_glTexSubImage3D},
{ glCopyTexSubImage3DFunc,  "glCopyTexSubImage3D", egl_copyTexSubImage3D, &esdl_glCopyTexSubImage3D},
{ glActiveTextureFunc,  "glActiveTexture", egl_activeTexture, &esdl_glActiveTexture},
{ glClientActiveTextureFunc,  "glClientActiveTexture", egl_clientActiveTexture, &esdl_glClientActiveTexture},
{ glMultiTexCoord1dvFunc,  "glMultiTexCoord1dv", egl_multiTexCoord1dv, &esdl_glMultiTexCoord1dv},
{ glMultiTexCoord1fvFunc,  "glMultiTexCoord1fv", egl_multiTexCoord1fv, &esdl_glMultiTexCoord1fv},
{ glMultiTexCoord1ivFunc,  "glMultiTexCoord1iv", egl_multiTexCoord1iv, &esdl_glMultiTexCoord1iv},
{ glMultiTexCoord1svFunc,  "glMultiTexCoord1sv", egl_multiTexCoord1sv, &esdl_glMultiTexCoord1sv},
{ glMultiTexCoord2dvFunc,  "glMultiTexCoord2dv", egl_multiTexCoord2dv, &esdl_glMultiTexCoord2dv},
{ glMultiTexCoord2fvFunc,  "glMultiTexCoord2fv", egl_multiTexCoord2fv, &esdl_glMultiTexCoord2fv},
{ glMultiTexCoord2ivFunc,  "glMultiTexCoord2iv", egl_multiTexCoord2iv, &esdl_glMultiTexCoord2iv},
{ glMultiTexCoord2svFunc,  "glMultiTexCoord2sv", egl_multiTexCoord2sv, &esdl_glMultiTexCoord2sv},
{ glMultiTexCoord3dvFunc,  "glMultiTexCoord3dv", egl_multiTexCoord3dv, &esdl_glMultiTexCoord3dv},
{ glMultiTexCoord3fvFunc,  "glMultiTexCoord3fv", egl_multiTexCoord3fv, &esdl_glMultiTexCoord3fv},
{ glMultiTexCoord3ivFunc,  "glMultiTexCoord3iv", egl_multiTexCoord3iv, &esdl_glMultiTexCoord3iv},
{ glMultiTexCoord3svFunc,  "glMultiTexCoord3sv", egl_multiTexCoord3sv, &esdl_glMultiTexCoord3sv},
{ glMultiTexCoord4dvFunc,  "glMultiTexCoord4dv", egl_multiTexCoord4dv, &esdl_glMultiTexCoord4dv},
{ glMultiTexCoord4fvFunc,  "glMultiTexCoord4fv", egl_multiTexCoord4fv, &esdl_glMultiTexCoord4fv},
{ glMultiTexCoord4ivFunc,  "glMultiTexCoord4iv", egl_multiTexCoord4iv, &esdl_glMultiTexCoord4iv},
{ glMultiTexCoord4svFunc,  "glMultiTexCoord4sv", egl_multiTexCoord4sv, &esdl_glMultiTexCoord4sv},
{ glLoadTransposeMatrixfFunc,  "glLoadTransposeMatrixf", egl_loadTransposeMatrixf, &esdl_glLoadTransposeMatrixf},
{ glLoadTransposeMatrixdFunc,  "glLoadTransposeMatrixd", egl_loadTransposeMatrixd, &esdl_glLoadTransposeMatrixd},
{ glMultTransposeMatrixfFunc,  "glMultTransposeMatrixf", egl_multTransposeMatrixf, &esdl_glMultTransposeMatrixf},
{ glMultTransposeMatrixdFunc,  "glMultTransposeMatrixd", egl_multTransposeMatrixd, &esdl_glMultTransposeMatrixd},
{ glSampleCoverageFunc,  "glSampleCoverage", egl_sampleCoverage, &esdl_glSampleCoverage},
{ glCompressedTexImage3DFunc,  "glCompressedTexImage3D", egl_compressedTexImage3D, &esdl_glCompressedTexImage3D},
{ glCompressedTexImage2DFunc,  "glCompressedTexImage2D", egl_compressedTexImage2D, &esdl_glCompressedTexImage2D},
{ glCompressedTexImage1DFunc,  "glCompressedTexImage1D", egl_compressedTexImage1D, &esdl_glCompressedTexImage1D},
{ glCompressedTexSubImage3DFunc,  "glCompressedTexSubImage3D", egl_compressedTexSubImage3D, &esdl_glCompressedTexSubImage3D},
{ glCompressedTexSubImage2DFunc,  "glCompressedTexSubImage2D", egl_compressedTexSubImage2D, &esdl_glCompressedTexSubImage2D},
{ glCompressedTexSubImage1DFunc,  "glCompressedTexSubImage1D", egl_compressedTexSubImage1D, &esdl_glCompressedTexSubImage1D},
{ glGetCompressedTexImageFunc,  "glGetCompressedTexImage", egl_getCompressedTexImage, &esdl_glGetCompressedTexImage},
{ glBlendFuncSeparateFunc,  "glBlendFuncSeparate", egl_blendFuncSeparate, &esdl_glBlendFuncSeparate},
{ glFogCoordfFunc,  "glFogCoordf", egl_fogCoordf, &esdl_glFogCoordf},
{ glFogCoordfvFunc,  "glFogCoordfv", egl_fogCoordfv, &esdl_glFogCoordfv},
{ glFogCoorddFunc,  "glFogCoordd", egl_fogCoordd, &esdl_glFogCoordd},
{ glFogCoorddvFunc,  "glFogCoorddv", egl_fogCoorddv, &esdl_glFogCoorddv},
{ glFogCoordPointerFunc,  "glFogCoordPointer", egl_fogCoordPointer, &esdl_glFogCoordPointer},
{ glMultiDrawArraysFunc,  "glMultiDrawArrays", egl_multiDrawArrays, &esdl_glMultiDrawArrays},
{ glPointParameterfFunc,  "glPointParameterf", egl_pointParameterf, &esdl_glPointParameterf},
{ glPointParameterfvFunc,  "glPointParameterfv", egl_pointParameterfv, &esdl_glPointParameterfv},
{ glPointParameteriFunc,  "glPointParameteri", egl_pointParameteri, &esdl_glPointParameteri},
{ glPointParameterivFunc,  "glPointParameteriv", egl_pointParameteriv, &esdl_glPointParameteriv},
{ glSecondaryColor3bvFunc,  "glSecondaryColor3bv", egl_secondaryColor3bv, &esdl_glSecondaryColor3bv},
{ glSecondaryColor3dvFunc,  "glSecondaryColor3dv", egl_secondaryColor3dv, &esdl_glSecondaryColor3dv},
{ glSecondaryColor3fvFunc,  "glSecondaryColor3fv", egl_secondaryColor3fv, &esdl_glSecondaryColor3fv},
{ glSecondaryColor3ivFunc,  "glSecondaryColor3iv", egl_secondaryColor3iv, &esdl_glSecondaryColor3iv},
{ glSecondaryColor3svFunc,  "glSecondaryColor3sv", egl_secondaryColor3sv, &esdl_glSecondaryColor3sv},
{ glSecondaryColor3ubvFunc,  "glSecondaryColor3ubv", egl_secondaryColor3ubv, &esdl_glSecondaryColor3ubv},
{ glSecondaryColor3uivFunc,  "glSecondaryColor3uiv", egl_secondaryColor3uiv, &esdl_glSecondaryColor3uiv},
{ glSecondaryColor3usvFunc,  "glSecondaryColor3usv", egl_secondaryColor3usv, &esdl_glSecondaryColor3usv},
{ glSecondaryColorPointerFunc,  "glSecondaryColorPointer", egl_secondaryColorPointer, &esdl_glSecondaryColorPointer},
{ glWindowPos2dvFunc,  "glWindowPos2dv", egl_windowPos2dv, &esdl_glWindowPos2dv},
{ glWindowPos2fvFunc,  "glWindowPos2fv", egl_windowPos2fv, &esdl_glWindowPos2fv},
{ glWindowPos2ivFunc,  "glWindowPos2iv", egl_windowPos2iv, &esdl_glWindowPos2iv},
{ glWindowPos2svFunc,  "glWindowPos2sv", egl_windowPos2sv, &esdl_glWindowPos2sv},
{ glWindowPos3dvFunc,  "glWindowPos3dv", egl_windowPos3dv, &esdl_glWindowPos3dv},
{ glWindowPos3fvFunc,  "glWindowPos3fv", egl_windowPos3fv, &esdl_glWindowPos3fv},
{ glWindowPos3ivFunc,  "glWindowPos3iv", egl_windowPos3iv, &esdl_glWindowPos3iv},
{ glWindowPos3svFunc,  "glWindowPos3sv", egl_windowPos3sv, &esdl_glWindowPos3sv},
{ glGenQueriesFunc,  "glGenQueries", egl_genQueries, &esdl_glGenQueries},
{ glDeleteQueriesFunc,  "glDeleteQueries", egl_deleteQueries, &esdl_glDeleteQueries},
{ glIsQueryFunc,  "glIsQuery", egl_isQuery, &esdl_glIsQuery},
{ glBeginQueryFunc,  "glBeginQuery", egl_beginQuery, &esdl_glBeginQuery},
{ glEndQueryFunc,  "glEndQuery", egl_endQuery, &esdl_glEndQuery},
{ glGetQueryivFunc,  "glGetQueryiv", egl_getQueryiv, &esdl_glGetQueryiv},
{ glGetQueryObjectivFunc,  "glGetQueryObjectiv", egl_getQueryObjectiv, &esdl_glGetQueryObjectiv},
{ glGetQueryObjectuivFunc,  "glGetQueryObjectuiv", egl_getQueryObjectuiv, &esdl_glGetQueryObjectuiv},
{ glBindBufferFunc,  "glBindBuffer", egl_bindBuffer, &esdl_glBindBuffer},
{ glDeleteBuffersFunc,  "glDeleteBuffers", egl_deleteBuffers, &esdl_glDeleteBuffers},
{ glGenBuffersFunc,  "glGenBuffers", egl_genBuffers, &esdl_glGenBuffers},
{ glIsBufferFunc,  "glIsBuffer", egl_isBuffer, &esdl_glIsBuffer},
{ glBufferDataFunc,  "glBufferData", egl_bufferData, &esdl_glBufferData},
{ glBufferSubDataFunc,  "glBufferSubData", egl_bufferSubData, &esdl_glBufferSubData},
{ glGetBufferSubDataFunc,  "glGetBufferSubData", egl_getBufferSubData, &esdl_glGetBufferSubData},
{ glUnmapBufferFunc,  "glUnmapBuffer", egl_unmapBuffer, &esdl_glUnmapBuffer},
{ glGetBufferParameterivFunc,  "glGetBufferParameteriv", egl_getBufferParameteriv, &esdl_glGetBufferParameteriv},
{ glGetBufferPointervFunc,  "glGetBufferPointerv", egl_getBufferPointerv, &esdl_glGetBufferPointerv},
{ glBlendEquationSeparateFunc,  "glBlendEquationSeparate", egl_blendEquationSeparate, &esdl_glBlendEquationSeparate},
{ glDrawBuffersFunc,  "glDrawBuffers", egl_drawBuffers, &esdl_glDrawBuffers},
{ glStencilOpSeparateFunc,  "glStencilOpSeparate", egl_stencilOpSeparate, &esdl_glStencilOpSeparate},
{ glStencilFuncSeparateFunc,  "glStencilFuncSeparate", egl_stencilFuncSeparate, &esdl_glStencilFuncSeparate},
{ glStencilMaskSeparateFunc,  "glStencilMaskSeparate", egl_stencilMaskSeparate, &esdl_glStencilMaskSeparate},
{ glAttachShaderFunc,  "glAttachShader", egl_attachShader, &esdl_glAttachShader},
{ glBindAttribLocationFunc,  "glBindAttribLocation", egl_bindAttribLocation, &esdl_glBindAttribLocation},
{ glCompileShaderFunc,  "glCompileShader", egl_compileShader, &esdl_glCompileShader},
{ glCreateProgramFunc,  "glCreateProgram", egl_createProgram, &esdl_glCreateProgram},
{ glCreateShaderFunc,  "glCreateShader", egl_createShader, &esdl_glCreateShader},
{ glDeleteProgramFunc,  "glDeleteProgram", egl_deleteProgram, &esdl_glDeleteProgram},
{ glDeleteShaderFunc,  "glDeleteShader", egl_deleteShader, &esdl_glDeleteShader},
{ glDetachShaderFunc,  "glDetachShader", egl_detachShader, &esdl_glDetachShader},
{ glDisableVertexAttribArrayFunc,  "glDisableVertexAttribArray", egl_disableVertexAttribArray, &esdl_glDisableVertexAttribArray},
{ glEnableVertexAttribArrayFunc,  "glEnableVertexAttribArray", egl_enableVertexAttribArray, &esdl_glEnableVertexAttribArray},
{ glGetActiveAttribFunc,  "glGetActiveAttrib", egl_getActiveAttrib, &esdl_glGetActiveAttrib},
{ glGetActiveUniformFunc,  "glGetActiveUniform", egl_getActiveUniform, &esdl_glGetActiveUniform},
{ glGetAttachedShadersFunc,  "glGetAttachedShaders", egl_getAttachedShaders, &esdl_glGetAttachedShaders},
{ glGetAttribLocationFunc,  "glGetAttribLocation", egl_getAttribLocation, &esdl_glGetAttribLocation},
{ glGetProgramivFunc,  "glGetProgramiv", egl_getProgramiv, &esdl_glGetProgramiv},
{ glGetProgramInfoLogFunc,  "glGetProgramInfoLog", egl_getProgramInfoLog, &esdl_glGetProgramInfoLog},
{ glGetShaderivFunc,  "glGetShaderiv", egl_getShaderiv, &esdl_glGetShaderiv},
{ glGetShaderInfoLogFunc,  "glGetShaderInfoLog", egl_getShaderInfoLog, &esdl_glGetShaderInfoLog},
{ glGetShaderSourceFunc,  "glGetShaderSource", egl_getShaderSource, &esdl_glGetShaderSource},
{ glGetUniformLocationFunc,  "glGetUniformLocation", egl_getUniformLocation, &esdl_glGetUniformLocation},
{ glGetUniformfvFunc,  "glGetUniformfv", egl_getUniformfv, &esdl_glGetUniformfv},
{ glGetUniformivFunc,  "glGetUniformiv", egl_getUniformiv, &esdl_glGetUniformiv},
{ glGetVertexAttribdvFunc,  "glGetVertexAttribdv", egl_getVertexAttribdv, &esdl_glGetVertexAttribdv},
{ glGetVertexAttribfvFunc,  "glGetVertexAttribfv", egl_getVertexAttribfv, &esdl_glGetVertexAttribfv},
{ glGetVertexAttribivFunc,  "glGetVertexAttribiv", egl_getVertexAttribiv, &esdl_glGetVertexAttribiv},
{ glGetVertexAttribPointervFunc,  "glGetVertexAttribPointerv", egl_getVertexAttribPointerv, &esdl_glGetVertexAttribPointerv},
{ glIsProgramFunc,  "glIsProgram", egl_isProgram, &esdl_glIsProgram},
{ glIsShaderFunc,  "glIsShader", egl_isShader, &esdl_glIsShader},
{ glLinkProgramFunc,  "glLinkProgram", egl_linkProgram, &esdl_glLinkProgram},
{ glShaderSourceFunc,  "glShaderSource", egl_shaderSource, &esdl_glShaderSource},
{ glUseProgramFunc,  "glUseProgram", egl_useProgram, &esdl_glUseProgram},
{ glUniform1fFunc,  "glUniform1f", egl_uniform1f, &esdl_glUniform1f},
{ glUniform2fFunc,  "glUniform2f", egl_uniform2f, &esdl_glUniform2f},
{ glUniform3fFunc,  "glUniform3f", egl_uniform3f, &esdl_glUniform3f},
{ glUniform4fFunc,  "glUniform4f", egl_uniform4f, &esdl_glUniform4f},
{ glUniform1iFunc,  "glUniform1i", egl_uniform1i, &esdl_glUniform1i},
{ glUniform2iFunc,  "glUniform2i", egl_uniform2i, &esdl_glUniform2i},
{ glUniform3iFunc,  "glUniform3i", egl_uniform3i, &esdl_glUniform3i},
{ glUniform4iFunc,  "glUniform4i", egl_uniform4i, &esdl_glUniform4i},
{ glUniform1fvFunc,  "glUniform1fv", egl_uniform1fv, &esdl_glUniform1fv},
{ glUniform2fvFunc,  "glUniform2fv", egl_uniform2fv, &esdl_glUniform2fv},
{ glUniform3fvFunc,  "glUniform3fv", egl_uniform3fv, &esdl_glUniform3fv},
{ glUniform4fvFunc,  "glUniform4fv", egl_uniform4fv, &esdl_glUniform4fv},
{ glUniform1ivFunc,  "glUniform1iv", egl_uniform1iv, &esdl_glUniform1iv},
{ glUniform2ivFunc,  "glUniform2iv", egl_uniform2iv, &esdl_glUniform2iv},
{ glUniform3ivFunc,  "glUniform3iv", egl_uniform3iv, &esdl_glUniform3iv},
{ glUniform4ivFunc,  "glUniform4iv", egl_uniform4iv, &esdl_glUniform4iv},
{ glUniformMatrix2fvFunc,  "glUniformMatrix2fv", egl_uniformMatrix2fv, &esdl_glUniformMatrix2fv},
{ glUniformMatrix3fvFunc,  "glUniformMatrix3fv", egl_uniformMatrix3fv, &esdl_glUniformMatrix3fv},
{ glUniformMatrix4fvFunc,  "glUniformMatrix4fv", egl_uniformMatrix4fv, &esdl_glUniformMatrix4fv},
{ glValidateProgramFunc,  "glValidateProgram", egl_validateProgram, &esdl_glValidateProgram},
{ glVertexAttrib1dvFunc,  "glVertexAttrib1dv", egl_vertexAttrib1dv, &esdl_glVertexAttrib1dv},
{ glVertexAttrib1fvFunc,  "glVertexAttrib1fv", egl_vertexAttrib1fv, &esdl_glVertexAttrib1fv},
{ glVertexAttrib1svFunc,  "glVertexAttrib1sv", egl_vertexAttrib1sv, &esdl_glVertexAttrib1sv},
{ glVertexAttrib2dvFunc,  "glVertexAttrib2dv", egl_vertexAttrib2dv, &esdl_glVertexAttrib2dv},
{ glVertexAttrib2fvFunc,  "glVertexAttrib2fv", egl_vertexAttrib2fv, &esdl_glVertexAttrib2fv},
{ glVertexAttrib2svFunc,  "glVertexAttrib2sv", egl_vertexAttrib2sv, &esdl_glVertexAttrib2sv},
{ glVertexAttrib3dvFunc,  "glVertexAttrib3dv", egl_vertexAttrib3dv, &esdl_glVertexAttrib3dv},
{ glVertexAttrib3fvFunc,  "glVertexAttrib3fv", egl_vertexAttrib3fv, &esdl_glVertexAttrib3fv},
{ glVertexAttrib3svFunc,  "glVertexAttrib3sv", egl_vertexAttrib3sv, &esdl_glVertexAttrib3sv},
{ glVertexAttrib4NbvFunc,  "glVertexAttrib4Nbv", egl_vertexAttrib4Nbv, &esdl_glVertexAttrib4Nbv},
{ glVertexAttrib4NivFunc,  "glVertexAttrib4Niv", egl_vertexAttrib4Niv, &esdl_glVertexAttrib4Niv},
{ glVertexAttrib4NsvFunc,  "glVertexAttrib4Nsv", egl_vertexAttrib4Nsv, &esdl_glVertexAttrib4Nsv},
{ glVertexAttrib4NubFunc,  "glVertexAttrib4Nub", egl_vertexAttrib4Nub, &esdl_glVertexAttrib4Nub},
{ glVertexAttrib4NubvFunc,  "glVertexAttrib4Nubv", egl_vertexAttrib4Nubv, &esdl_glVertexAttrib4Nubv},
{ glVertexAttrib4NuivFunc,  "glVertexAttrib4Nuiv", egl_vertexAttrib4Nuiv, &esdl_glVertexAttrib4Nuiv},
{ glVertexAttrib4NusvFunc,  "glVertexAttrib4Nusv", egl_vertexAttrib4Nusv, &esdl_glVertexAttrib4Nusv},
{ glVertexAttrib4bvFunc,  "glVertexAttrib4bv", egl_vertexAttrib4bv, &esdl_glVertexAttrib4bv},
{ glVertexAttrib4dvFunc,  "glVertexAttrib4dv", egl_vertexAttrib4dv, &esdl_glVertexAttrib4dv},
{ glVertexAttrib4fvFunc,  "glVertexAttrib4fv", egl_vertexAttrib4fv, &esdl_glVertexAttrib4fv},
{ glVertexAttrib4ivFunc,  "glVertexAttrib4iv", egl_vertexAttrib4iv, &esdl_glVertexAttrib4iv},
{ glVertexAttrib4svFunc,  "glVertexAttrib4sv", egl_vertexAttrib4sv, &esdl_glVertexAttrib4sv},
{ glVertexAttrib4ubvFunc,  "glVertexAttrib4ubv", egl_vertexAttrib4ubv, &esdl_glVertexAttrib4ubv},
{ glVertexAttrib4uivFunc,  "glVertexAttrib4uiv", egl_vertexAttrib4uiv, &esdl_glVertexAttrib4uiv},
{ glVertexAttrib4usvFunc,  "glVertexAttrib4usv", egl_vertexAttrib4usv, &esdl_glVertexAttrib4usv},
{ glVertexAttribPointerFunc,  "glVertexAttribPointer", egl_vertexAttribPointer, &esdl_glVertexAttribPointer},
{ glWeightbvARBFunc,  "glWeightbvARB", egl_weightbvARB, &esdl_glWeightbvARB},
{ glWeightsvARBFunc,  "glWeightsvARB", egl_weightsvARB, &esdl_glWeightsvARB},
{ glWeightivARBFunc,  "glWeightivARB", egl_weightivARB, &esdl_glWeightivARB},
{ glWeightfvARBFunc,  "glWeightfvARB", egl_weightfvARB, &esdl_glWeightfvARB},
{ glWeightdvARBFunc,  "glWeightdvARB", egl_weightdvARB, &esdl_glWeightdvARB},
{ glWeightubvARBFunc,  "glWeightubvARB", egl_weightubvARB, &esdl_glWeightubvARB},
{ glWeightusvARBFunc,  "glWeightusvARB", egl_weightusvARB, &esdl_glWeightusvARB},
{ glWeightuivARBFunc,  "glWeightuivARB", egl_weightuivARB, &esdl_glWeightuivARB},
{ glWeightPointerARBFunc,  "glWeightPointerARB", egl_weightPointerARB, &esdl_glWeightPointerARB},
{ glVertexBlendARBFunc,  "glVertexBlendARB", egl_vertexBlendARB, &esdl_glVertexBlendARB},
{ glCurrentPaletteMatrixARBFunc,  "glCurrentPaletteMatrixARB", egl_currentPaletteMatrixARB, &esdl_glCurrentPaletteMatrixARB},
{ glMatrixIndexubvARBFunc,  "glMatrixIndexubvARB", egl_matrixIndexubvARB, &esdl_glMatrixIndexubvARB},
{ glMatrixIndexusvARBFunc,  "glMatrixIndexusvARB", egl_matrixIndexusvARB, &esdl_glMatrixIndexusvARB},
{ glMatrixIndexuivARBFunc,  "glMatrixIndexuivARB", egl_matrixIndexuivARB, &esdl_glMatrixIndexuivARB},
{ glMatrixIndexPointerARBFunc,  "glMatrixIndexPointerARB", egl_matrixIndexPointerARB, &esdl_glMatrixIndexPointerARB},
{ glProgramStringARBFunc,  "glProgramStringARB", egl_programStringARB, &esdl_glProgramStringARB},
{ glBindProgramARBFunc,  "glBindProgramARB", egl_bindProgramARB, &esdl_glBindProgramARB},
{ glDeleteProgramsARBFunc,  "glDeleteProgramsARB", egl_deleteProgramsARB, &esdl_glDeleteProgramsARB},
{ glGenProgramsARBFunc,  "glGenProgramsARB", egl_genProgramsARB, &esdl_glGenProgramsARB},
{ glProgramEnvParameter4dvARBFunc,  "glProgramEnvParameter4dvARB", egl_programEnvParameter4dvARB, &esdl_glProgramEnvParameter4dvARB},
{ glProgramEnvParameter4fvARBFunc,  "glProgramEnvParameter4fvARB", egl_programEnvParameter4fvARB, &esdl_glProgramEnvParameter4fvARB},
{ glProgramLocalParameter4dvARBFunc,  "glProgramLocalParameter4dvARB", egl_programLocalParameter4dvARB, &esdl_glProgramLocalParameter4dvARB},
{ glProgramLocalParameter4fvARBFunc,  "glProgramLocalParameter4fvARB", egl_programLocalParameter4fvARB, &esdl_glProgramLocalParameter4fvARB},
{ glGetProgramEnvParameterdvARBFunc,  "glGetProgramEnvParameterdvARB", egl_getProgramEnvParameterdvARB, &esdl_glGetProgramEnvParameterdvARB},
{ glGetProgramEnvParameterfvARBFunc,  "glGetProgramEnvParameterfvARB", egl_getProgramEnvParameterfvARB, &esdl_glGetProgramEnvParameterfvARB},
{ glGetProgramLocalParameterdvARBFunc,  "glGetProgramLocalParameterdvARB", egl_getProgramLocalParameterdvARB, &esdl_glGetProgramLocalParameterdvARB},
{ glGetProgramLocalParameterfvARBFunc,  "glGetProgramLocalParameterfvARB", egl_getProgramLocalParameterfvARB, &esdl_glGetProgramLocalParameterfvARB},
{ glGetProgramStringARBFunc,  "glGetProgramStringARB", egl_getProgramStringARB, &esdl_glGetProgramStringARB},
{ glDeleteObjectARBFunc,  "glDeleteObjectARB", egl_deleteObjectARB, &esdl_glDeleteObjectARB},
{ glGetHandleARBFunc,  "glGetHandleARB", egl_getHandleARB, &esdl_glGetHandleARB},
{ glDetachObjectARBFunc,  "glDetachObjectARB", egl_detachObjectARB, &esdl_glDetachObjectARB},
{ glCreateShaderObjectARBFunc,  "glCreateShaderObjectARB", egl_createShaderObjectARB, &esdl_glCreateShaderObjectARB},
{ glCreateProgramObjectARBFunc,  "glCreateProgramObjectARB", egl_createProgramObjectARB, &esdl_glCreateProgramObjectARB},
{ glAttachObjectARBFunc,  "glAttachObjectARB", egl_attachObjectARB, &esdl_glAttachObjectARB},
{ glUseProgramObjectARBFunc,  "glUseProgramObjectARB", egl_useProgramObjectARB, &esdl_glUseProgramObjectARB},
{ glGetObjectParameterfvARBFunc,  "glGetObjectParameterfvARB", egl_getObjectParameterfvARB, &esdl_glGetObjectParameterfvARB},
{ glGetObjectParameterivARBFunc,  "glGetObjectParameterivARB", egl_getObjectParameterivARB, &esdl_glGetObjectParameterivARB},
{ glGetInfoLogARBFunc,  "glGetInfoLogARB", egl_getInfoLogARB, &esdl_glGetInfoLogARB},
{ glGetAttachedObjectsARBFunc,  "glGetAttachedObjectsARB", egl_getAttachedObjectsARB, &esdl_glGetAttachedObjectsARB},
{ glStencilOpSeparateATIFunc,  "glStencilOpSeparateATI", egl_stencilOpSeparateATI, &esdl_glStencilOpSeparateATI},
{ glStencilFuncSeparateATIFunc,  "glStencilFuncSeparateATI", egl_stencilFuncSeparateATI, &esdl_glStencilFuncSeparateATI},
{ glIsRenderbufferEXTFunc,  "glIsRenderbufferEXT", egl_isRenderbufferEXT, &esdl_glIsRenderbufferEXT},
{ glBindRenderbufferEXTFunc,  "glBindRenderbufferEXT", egl_bindRenderbufferEXT, &esdl_glBindRenderbufferEXT},
{ glDeleteRenderbuffersEXTFunc,  "glDeleteRenderbuffersEXT", egl_deleteRenderbuffersEXT, &esdl_glDeleteRenderbuffersEXT},
{ glGenRenderbuffersEXTFunc,  "glGenRenderbuffersEXT", egl_genRenderbuffersEXT, &esdl_glGenRenderbuffersEXT},
{ glRenderbufferStorageEXTFunc,  "glRenderbufferStorageEXT", egl_renderbufferStorageEXT, &esdl_glRenderbufferStorageEXT},
{ glGetRenderbufferParameterivEXTFunc,  "glGetRenderbufferParameterivEXT", egl_getRenderbufferParameterivEXT, &esdl_glGetRenderbufferParameterivEXT},
{ glIsFramebufferEXTFunc,  "glIsFramebufferEXT", egl_isFramebufferEXT, &esdl_glIsFramebufferEXT},
{ glBindFramebufferEXTFunc,  "glBindFramebufferEXT", egl_bindFramebufferEXT, &esdl_glBindFramebufferEXT},
{ glDeleteFramebuffersEXTFunc,  "glDeleteFramebuffersEXT", egl_deleteFramebuffersEXT, &esdl_glDeleteFramebuffersEXT},
{ glGenFramebuffersEXTFunc,  "glGenFramebuffersEXT", egl_genFramebuffersEXT, &esdl_glGenFramebuffersEXT},
{ glCheckFramebufferStatusEXTFunc,  "glCheckFramebufferStatusEXT", egl_checkFramebufferStatusEXT, &esdl_glCheckFramebufferStatusEXT},
{ glFramebufferTexture1DEXTFunc,  "glFramebufferTexture1DEXT", egl_framebufferTexture1DEXT, &esdl_glFramebufferTexture1DEXT},
{ glFramebufferTexture2DEXTFunc,  "glFramebufferTexture2DEXT", egl_framebufferTexture2DEXT, &esdl_glFramebufferTexture2DEXT},
{ glFramebufferTexture3DEXTFunc,  "glFramebufferTexture3DEXT", egl_framebufferTexture3DEXT, &esdl_glFramebufferTexture3DEXT},
{ glFramebufferRenderbufferEXTFunc,  "glFramebufferRenderbufferEXT", egl_framebufferRenderbufferEXT, &esdl_glFramebufferRenderbufferEXT},
{ glGetFramebufferAttachmentParameterivEXTFunc,  "glGetFramebufferAttachmentParameterivEXT", egl_getFramebufferAttachmentParameterivEXT, &esdl_glGetFramebufferAttachmentParameterivEXT},
{ glGenerateMipmapEXTFunc,  "glGenerateMipmapEXT", egl_generateMipmapEXT, &esdl_glGenerateMipmapEXT},
